Overview
========
This is an Infinidat project.

Usage
-----
Nothing to use here.

Checking out the code
=====================
Run the following commands:

    easy_install -U infi.projector
    projector devenv build

Supported Operating Systems
===========================
This project should work on both Unix based operating systems and on Windows based operating systems.
Due to a bug in pyzmq, this project DOES NOT work on AIX.

Python 3 Support
================
Python 3 support is experimental and not fully tested.